import logging

from google.oauth2 import service_account
from googleapiclient import discovery

# Create logger object
logger = logging.getLogger(__name__)


def get_service(
        api_name: str,
        api_version: str,
        credential_filename: str,
        credential_scopes: list) -> discovery.Resource:
    """
    Helper function to create service objects for Google APIs.

    Parameters
    ----------
    api_name : str
        The name of the API endpoint.
    api_version : str
        The version of the API endpoint.
    credential_filename : str
        The name of the service account file.
    credential_scopes : list
        List of OAuth 2.0 Scopes for Google APIs.

    Notes
    -----
    Applied cache_discovery=False to silence log errors.
    https://github.com/googleapis/google-api-python-client/issues/299

    References
    ----------
    https://developers.google.com/identity/protocols/OAuth2ServiceAccount
    https://developers.google.com/identity/protocols/googlescopes
    """

    # Reading credentials
    logger.info(f"Reading credentials from {credential_filename}")
    credentials = service_account.Credentials.from_service_account_file(
        credential_filename,
        scopes=credential_scopes,
    )

    # Create service object
    logger.info(f"Creating service object for {api_name} {api_version}")
    service = discovery.build(
        api_name,
        api_version,
        credentials=credentials,
        cache_discovery=False,
    )
    return service
